#!/usr/bin/env bash

###############################################################
# 脚本是 shell 文件，只适用于 mac 系统
# 执行脚本时，版本号为必填参数
# 在项目路径下执行命令：./android_build.sh 版本号
# 若出现提示 `zsh: command not found: android_build.sh`
# 解决方法：
# 1. vim ~/.zshrc
# 2. 找到 “# User configuration” 在其位置下面加 `source ~/.bash_profile`
# 3. 保存退出
# 4. source ~/.zshrc
###############################################################

# 在执行出错时结束程序
set -e

# 读取版本号
version=$1

###### 1. 检查参数
if [ ! -n  "$version" ]; then

echo ">>> 版本号参数不能为空!"

# 结束脚本运行
exit
fi

###### 2. 获取/更新包

echo ">>> 执行 flutter pub get!"

flutter pub get

###### 3. 构建依赖项目的AAR

echo ">>> 执行构建 ${version} release 版本 aar !"

#可选打包
#flutter build aar --no-release --no-profile --no-debug
flutter build aar --no-debug --no-profile --build-number ${version}

echo ">>> 构建成功"

###### 4. 将文件上传 maven

echo ">>> 执行上传 Maven"

file_path="build/host/outputs/repo/com/newchic/flutter/flutter_release/$version/flutter_release-$version"

mvn deploy:deploy-file \
-s="mvn-settings.xml" \
-DpomFile="$file_path.pom" \
-DgeneratePom=true \
-Dfile="$file_path.aar" \
-Durl="https://oss.bgapps.cn/repository/banggood-release" \
-DrepositoryId="com.newchic.flutter" \
-DgroupId="com.newchic.flutter" \
-Dpackaging=aar

echo ">>> 上传成功"

###### 5. 提示如何引入

echo ">>> 项目接入地址："

echo ">>> implementation 'com.newchic.flutter:flutter_release:$version'"